# -*- coding: utf-8 -*-

"""
    pepipost.pepipost_client

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""
from .decorators import lazy_property
from .configuration import Configuration
from .controllers.email_controller import EmailController

class PepipostClient(object):

    config = Configuration

    @lazy_property
    def email(self):
        return EmailController()



